macro_rules! sql_fetch_one_map {
($store:expr, $sql:expr, |$q:ident| $bind:expr, |$row:ident| $map:expr) => { ... };
}Expand description
Fetch exactly one row and map it through a closure.
macro_rules! sql_fetch_one_map {
($store:expr, $sql:expr, |$q:ident| $bind:expr, |$row:ident| $map:expr) => { ... };
}Fetch exactly one row and map it through a closure.